summaryrefslogtreecommitdiffstats
path: root/src/entryiconfactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryiconfactory.cpp')
-rw-r--r--src/entryiconfactory.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/entryiconfactory.cpp b/src/entryiconfactory.cpp
index 0f4696d..776b324 100644
--- a/src/entryiconfactory.cpp
+++ b/src/entryiconfactory.cpp
@@ -17,27 +17,27 @@
#include <kiconloader.h>
#include <kimageeffect.h>
-#include <qimage.h>
+#include <tqimage.h>
using Tellico::EntryIconFactory;
-EntryIconFactory::EntryIconFactory(int size_) : QIconFactory(), m_size(size_) {
+EntryIconFactory::EntryIconFactory(int size_) : TQIconFactory(), m_size(size_) {
setAutoDelete(true);
}
-QPixmap* EntryIconFactory::createPixmap(const QIconSet&, QIconSet::Size, QIconSet::Mode, QIconSet::State) {
- QPixmap entryPix = UserIcon(Kernel::self()->collectionTypeName());
+TQPixmap* EntryIconFactory::createPixmap(const TQIconSet&, TQIconSet::Size, TQIconSet::Mode, TQIconSet::State) {
+ TQPixmap entryPix = UserIcon(Kernel::self()->collectionTypeName());
// if we're 22x22 or smaller, just use entry icon
if(m_size < 23) {
- QImage entryImg = entryPix.convertToImage();
- entryPix.convertFromImage(entryImg.smoothScale(m_size, m_size, QImage::ScaleMin), 0);
- return new QPixmap(entryPix);
+ TQImage entryImg = entryPix.convertToImage();
+ entryPix.convertFromImage(entryImg.smoothScale(m_size, m_size, TQ_ScaleMin), 0);
+ return new TQPixmap(entryPix);
}
- QPixmap newPix = BarIcon(QString::fromLatin1("mime_empty"), m_size);
- QImage newImg = newPix.convertToImage();
-// QImage blend; Not exactly sure what the coordinates mean, but this seems to work ok.
+ TQPixmap newPix = BarIcon(TQString::tqfromLatin1("mime_empty"), m_size);
+ TQImage newImg = newPix.convertToImage();
+// TQImage blend; Not exactly sure what the coordinates mean, but this seems to work ok.
KImageEffect::blendOnLower(m_size/4, m_size/4, entryPix.convertToImage(), newImg);
newPix.convertFromImage(newImg, 0);
- return new QPixmap(newPix);
+ return new TQPixmap(newPix);
}